@@ -5,7 +5,7 @@ use warnings;
 use strict;
 use 5.010001;
 
-our $VERSION = '1.113_02';
+our $VERSION = '1.113_03';
 
 use Term::ReadKey qw( GetTerminalSize ReadKey ReadMode );
 
@@ -24,7 +24,26 @@ sub __get_key_OS {
     return if ! defined $c1;
     if ( $c1 eq "\e" ) {
         my $c2 = ReadKey( 0.10 );
-        if ( ! defined $c2 ) { return KEY_ESC; } # unused
+           if ( ! defined $c2 ) { return KEY_ESC; } # unused
+        #elsif ( $c3 eq 'A' ) { return VK_UP; }     vt 52
+        #elsif ( $c3 eq 'B' ) { return VK_DOWN; }
+        #elsif ( $c3 eq 'C' ) { return VK_RIGHT; }
+        #elsif ( $c3 eq 'D' ) { return VK_LEFT; }
+        #elsif ( $c3 eq 'H' ) { return VK_HOME; }
+        #elsif ( $c3 eq 'Z' ) { return KEY_BTAB; }
+        elsif ( $c2 eq 'O' ) {
+            my $c3 = ReadKey( 0 );
+               if ( $c3 eq 'A' ) { return VK_UP; }
+            elsif ( $c3 eq 'B' ) { return VK_DOWN; }
+            elsif ( $c3 eq 'C' ) { return VK_RIGHT; }
+            elsif ( $c3 eq 'D' ) { return VK_LEFT; }
+            elsif ( $c3 eq 'F' ) { return VK_END; }
+            elsif ( $c3 eq 'H' ) { return VK_HOME; }
+            elsif ( $c3 eq 'Z' ) { return KEY_BTAB; } #
+            else {
+                return NEXT_get_key;
+            }
+        }
         elsif ( $c2 eq '[' ) {
             my $c3 = ReadKey( 0 );
                if ( $c3 eq 'A' ) { return VK_UP; }
@@ -33,7 +52,7 @@ sub __get_key_OS {
             elsif ( $c3 eq 'D' ) { return VK_LEFT; }
             elsif ( $c3 eq 'F' ) { return VK_END; }
             elsif ( $c3 eq 'H' ) { return VK_HOME; }
-            elsif ( $c3 eq 'Z' ) { return KEY_BTAB; }
+            elsif ( $c3 eq 'Z' ) { return KEY_BTAB; } #
             elsif ( $c3 =~ /^[0-9]$/ ) {
                 my $c4 = ReadKey( 0 );
                 if ( $c4 eq '~' ) {
